function varargout = rvt(varargin)
% RVT M-file for rvt.fig
%      RVT, by itself, creates a new RVT or raises the existing
%      singleton*.
%
%      H = RVT returns the handle to a new RVT or the handle to
%      the existing singleton*.
%
%      RVT('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in RVT.M with the given input arguments.
%
%      RVT('Property','Value',...) creates a new RVT or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before rvt_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to rvt_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help rvt

% Last Modified by GUIDE v2.5 04-Apr-2007 16:14:26

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @rvt_OpeningFcn, ...
                   'gui_OutputFcn',  @rvt_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin & isstr(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before rvt is made visible.
function rvt_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to rvt (see VARARGIN)

% Choose default command line output for rvt
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes rvt wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = rvt_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in button.
function button_Callback(hObject, eventdata, handles)
% hObject    handle to button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

a2=0.0001;


xMax=1;
tMax=2.5;

n=str2double(get(handles.n,'String'));
% v priestorovej premennej

m= str2double(get(handles.m,'String'));
% v case

h=xMax/(n+1);
k=tMax/m;

set(handles.krok_k,'String',k);
set(handles.krok_h,'String',h);

clf=a2*k/(h^2);

set(handles.clf,'String',clf);


u0=inline('100*x.*(1-x)'); % zaciatocna podmienka
ries(1:n+2,1)=u0(h.*(0:n+1))';

% okrajove podmienky
alfa=0;
beta=0;
ries(1,2:m+1)=alfa;
ries(n+2,2:m+1)=beta;

for i=2:n+1, % priestorova premenna
    for j=2:m+1, % casova vrstva
        ries(i,j)=ries(i,j-1)+clf*(ries(i-1,j-1)-2*ries(i,j-1)+ries(i+1,j-1));
    end;
end;

%disp(clf)


priestor=0:h:xMax;
cas=0:k:tMax;
[t,x]=meshgrid(cas,priestor);
 
surf(t,x,ries); xlabel('cas t'); ylabel('poloha x'); zlabel('u(t,x)');
    



% --- Executes during object creation, after setting all properties.
function m_CreateFcn(hObject, eventdata, handles)
% hObject    handle to m (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function m_Callback(hObject, eventdata, handles)
% hObject    handle to m (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of m as text
%        str2double(get(hObject,'String')) returns contents of m as a double


% --- Executes during object creation, after setting all properties.
function n_CreateFcn(hObject, eventdata, handles)
% hObject    handle to n (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc
    set(hObject,'BackgroundColor','white');
else
    set(hObject,'BackgroundColor',get(0,'defaultUicontrolBackgroundColor'));
end



function n_Callback(hObject, eventdata, handles)
% hObject    handle to n (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of n as text
%        str2double(get(hObject,'String')) returns contents of n as a double


